LspCore

Struct LspCore 

pub struct LspCore { /* private fields */ }
The headless LSP core state machine.

This struct contains all the state and logic for the language server, independent of the platform-specific event loop. Both native and WASM implementations use this core.

Implementations

Source

impl LspCore

pub fn new() -> Self

Create a new LspCore instance.

pub fn runtime_mut(&mut self) -> &mut QueryRuntime

Get a mutable reference to the query runtime.

This is useful for registering workspaces during initialization.

pub fn is_initialized(&self) -> bool

Check if the server has been initialized.

pub fn set_initialized(&mut self)

Mark the server as initialized.

pub fn pending_files(&self) -> impl Iterator<Item = &TextFile>

Get pending files that need to be fetched.

pub fn pending_globs(&self) -> impl Iterator<Item = (&str, &Glob)>

Get pending glob patterns that need to be expanded.

pub fn open_document(&mut self, uri: &str, content: String)

Open a document and cache its content.

This should be called when a textDocument/didOpen notification is received.

pub fn change_document(&mut self, uri: &str, content: String)

Update a document’s content.

This should be called when a textDocument/didChange notification is received.

pub fn close_document(&mut self, uri: &str)

Close a document and clear its cached content.

This should be called when a textDocument/didClose notification is received.

pub fn get_document(&self, uri: &str) -> Option<&String>

Get the cached content of a document.

pub fn handle_request( &mut self, id: CoreRequestId, method: &str, params: Value, ) -> (Vec<LspOutput>, Vec<Effect>)

Handle an LSP request.

Returns outputs to send to the client and effects for the platform to perform.

pub fn cancel_request(&mut self, id: &CoreRequestId)

Cancel a pending request.

pub fn handle_notification( &mut self, method: &str, params: Value, ) -> (Vec<LspOutput>, Vec<Effect>)

Handle an LSP notification.

Returns outputs to send to the client and effects for the platform to perform.

pub fn resolve_file( &mut self, file: TextFile, content: Result<String, String>, ) -> (Vec<LspOutput>, Vec<Effect>)

Resolve a file asset with its content.

Returns outputs (responses, notifications) and effects for any newly pending assets.

pub fn resolve_glob( &mut self, id: &str, files: Vec<TextFile>, ) -> (Vec<LspOutput>, Vec<Effect>)

Resolve a glob pattern with matching files.

Returns outputs (responses, notifications) and effects for any newly pending assets.